@@ -24,6 +24,11 @@ class StaticUtils:
          
          raise ValueError("".join(message))
    
+   @staticmethod
+   def confirm(condition, message):
+      if not condition:
+         raise ValueError(message)
+   
    @staticmethod
    def findKeyInDictionary(dictionary, key):
       result = []
